#!/bin/sh

ltu_tar="dune-ltu-0.4.7.tar.gz"

if [ -z "`cat /proc/cpuinfo | grep 'MIPS 74K'`" ] ; then
	echo "ERROR: This package intended only for Sigma Design SMP864x CPU!"
	exit 1
fi

if [ ! -d /persistfs ] || ! mountpoint -q /persistfs ; then
	echo "ERROR: System storage (/persistfs) not installed!"
	echo "SOLUTION: Please create system storage first."
	exit 1
fi

if [ ! -f "$ltu_tar" ] ; then
	echo "ERROR: package file \"$ltu_tar\" not found!"
	exit 1
fi

if [ -x /persistfs/ltu/rc ] ; then
	echo -n "Stopping existing LTU: "
	/persistfs/ltu/rc stop >/dev/null 2>&1
	echo "[  OK  ]"
fi

# try to unbind system script (binded under build 0.2 and 0.1)
umount /firmware/scripts/reset_settings.sh 2>/dev/null

echo -n "Extracting package: "
tar -xzf "$ltu_tar" -C /persistfs

if [ ! -f /persistfs/ltu/rc ] ; then
	echo "[FAILED]"
	echo "ERROR: unable to extract package to destination /persistfs/ltu!"
	exit 1
fi

echo "[  OK  ]"

echo -n "Configuring package: "

mkdir -p /persistfs/ltu/home

# remove old boot script
rm -f /persistfs/ltu/boot/ltu.sh

# create default conf files
[ ! -f /persistfs/ltu/etc/exports ] && cp /persistfs/ltu/etc/default/exports /persistfs/ltu/etc

# create default LTU configure
SAVE_PASSWD=0
START_TELNET=1
START_SSH=0
START_NFSD=0
START_TRANSMISSION=0
USE_FTP_SERVER=1
USE_FIX_TCP_RMEM=0
HDD_SPINDOWN_TIME=30
HDD_APM_DISABLE=0
HDD_AAM_QUIET=0
[ -r /persistfs/ltu/configure ] && . /persistfs/ltu/configure

echo "
# store users, groups and passwords on system storage
SAVE_PASSWD=$SAVE_PASSWD

# start Telnet terminal server
START_TELNET=$START_TELNET

# start SSH terminal server (0=OFF, 1=Dropbear)
START_SSH=$START_SSH

# start NFS server
START_NFSD=$START_NFSD

# start bittorent transmission-daemon
START_TRANSMISSION=$START_TRANSMISSION

# select FTP server (0=disable FTP server, 1=use original vsftpd, 2=use secure Pure-FTPd server with virtual users database)
USE_FTP_SERVER=$USE_FTP_SERVER

# use fixed TCP receive window for prevent kernel crash (0=auto fix on start transmission/aria2/microdc2, 1=force fix on start LTU)
USE_FIX_TCP_RMEM=$USE_FIX_TCP_RMEM

# set HDD idle spindown time in minutes for HDD drives (0=not change, valid values 5/10/15/20/30/60/90/120/150/180 min)
HDD_SPINDOWN_TIME=$HDD_SPINDOWN_TIME

# disable HDD advanced power management for decrease Load_Cycle_Count (0=not change, 1=disable APM)
HDD_APM_DISABLE=$HDD_APM_DISABLE

# set HDD advanced acoustic management to quiet mode (0=not change, 1=AAM quiet)
HDD_AAM_QUIET=$HDD_AAM_QUIET" > /persistfs/ltu/configure

chmod 644 /persistfs/ltu/configure

echo "[  OK  ]"

echo -n "Installing package: "
/persistfs/ltu/rc install >/dev/null 2>&1

echo "[  OK  ]"

